@@ -118,9 +118,7 @@ QString DStandardPaths::homePath()
     if (!home.isEmpty())
         return QString::fromLocal8Bit(home);
 
-    struct passwd *pw = getpwuid(getuid());
-    const char *homedir = pw->pw_dir;
-    return QString::fromLocal8Bit(homedir);
+    return homePath(getuid());
 }
 
 QString DStandardPaths::path(DStandardPaths::XDG type)
@@ -144,12 +142,23 @@ QString DStandardPaths::path(DStandardPaths::XDG type)
             return QString::fromLocal8Bit(path);
         return homePath() + QStringLiteral("/.config");
     }
-    case XDG::RuntimeTime: {
+    case XDG::RuntimeDir: {
         const QByteArray &path = qgetenv("XDG_RUNTIME_DIR");
         if (!path.isEmpty())
             return QString::fromLocal8Bit(path);
         return QStringLiteral("/run/user/") + QString::number(getuid());
     }
+    case XDG::StateHome: {
+        const QByteArray &path = qgetenv("XDG_STATE_HOME");
+        if (!path.isEmpty())
+            return QString::fromLocal8Bit(path);
+#ifdef Q_OS_LINUX
+        return homePath() + QStringLiteral("/.local/state");
+#else
+        // TODO: handle it on mac
+        return QString();
+#endif
+    }
     }
     return QString();
 }
