@@ -1,4 +1,8 @@
-#include "gsettingsbackend.h"
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
+
+#include "settings/backend/gsettingsbackend.h"
 
 //#include <QDebug>
 #include <QFile>
@@ -50,9 +54,10 @@ public:
 };
 
 /*!
-  \class Dtk::Core::GSettingsBackend
+@~english
+  @class Dtk::Core::GSettingsBackend
   \inmodule dtkcore
-  \brief Storage backend of DSettings use gsettings.
+  @brief Storage backend of DSettings use gsettings.
   
   You should generate gsetting schema with /usr/lib/x86_64-linux-gnu/libdtk-$$VERSION/DCore/bin/dtk-settings.
   
@@ -90,8 +95,9 @@ GSettingsBackend::~GSettingsBackend()
 }
 
 /*!
-  \brief List all gsettings keys.
-  \return Return all gsettings keys.
+@~english
+  @brief List all gsettings keys.
+  @return Return all gsettings keys.
  */
 QStringList GSettingsBackend::keys() const
 {
@@ -100,8 +106,9 @@ QStringList GSettingsBackend::keys() const
 }
 
 /*!
-  \brief Get value of key.
-  \return Return the value of the given \a key.
+@~english
+  @brief Get value of key.
+  @return Return the value of the given \a key.
  */
 QVariant GSettingsBackend::getOption(const QString &key) const
 {
@@ -110,7 +117,8 @@ QVariant GSettingsBackend::getOption(const QString &key) const
 }
 
 /*!
-  \brief Set value to gsettings
+@~english
+  @brief Set value to gsettings
   Use the \a key to save the \a value.
  */
 void GSettingsBackend::doSetOption(const QString &key, const QVariant &value)
@@ -123,7 +131,8 @@ void GSettingsBackend::doSetOption(const QString &key, const QVariant &value)
 }
 
 /*!
-  \brief Trigger DSettings to sync option to storage.
+@~english
+  @brief Trigger DSettings to sync option to storage.
  */
 void GSettingsBackend::doSync()
 {
