@@ -1,21 +1,8 @@
-/*
- * Copyright (C) 2016 ~ 2017 Deepin Technology Co., Ltd.
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2016 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
 
-#include "qsettingbackend.h"
+#include "settings/backend/qsettingbackend.h"
 
 #include <QDebug>
 #include <QMutex>
@@ -36,13 +23,15 @@ public:
 };
 
 /*!
-  \class Dtk::Core::QSettingBackend
+@~english
+  @class Dtk::Core::QSettingBackend
   \inmodule dtkcore
-  \brief Storage DSetttings to an QSettings.
+  @brief Storage DSetttings to an QSettings.
  */
 
 /*!
-  \brief Save data to filepath with QSettings::NativeFormat format.
+@~english
+  @brief Save data to filepath with QSettings::NativeFormat format.
   \a filepath is path to storage data.
   \a parent
  */
@@ -61,8 +50,9 @@ QSettingBackend::~QSettingBackend()
 }
 
 /*!
-  \brief List all keys of QSettings
-  \return
+@~english
+  @brief List all keys of QSettings
+  @return
  */
 QStringList QSettingBackend::keys() const
 {
@@ -71,9 +61,10 @@ QStringList QSettingBackend::keys() const
 }
 
 /*!
-  \brief Get value of key from QSettings
+@~english
+  @brief Get value of key from QSettings
   \a key
-  \return
+  @return
  */
 QVariant QSettingBackend::getOption(const QString &key) const
 {
@@ -85,7 +76,8 @@ QVariant QSettingBackend::getOption(const QString &key) const
 }
 
 /*!
-  \brief Set value of key to QSettings
+@~english
+  @brief Set value of key to QSettings
   \a key
   \a value
  */
@@ -104,7 +96,8 @@ void QSettingBackend::doSetOption(const QString &key, const QVariant &value)
 }
 
 /*!
-  \brief Trigger DSettings to save option value to QSettings
+@~english
+  @brief Trigger DSettings to save option value to QSettings
  */
 void QSettingBackend::doSync()
 {
