@@ -1,19 +1,6 @@
-/*
- * Copyright (C) 2016 ~ 2017 Deepin Technology Co., Ltd.
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2016 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
 
 #include "dsettings.h"
 
@@ -49,13 +36,14 @@ public:
 
 
 /*!
-   \class Dtk::Core::DSettingsBackend
+@~english
+   @class Dtk::Core::DSettingsBackend
    \inmodule dtkcore
-   \brief DSettingsBackend is interface of DSettings storage class.
+   @brief DSettingsBackend is interface of DSettings storage class.
 
    Simaple example:
 
-\code
+@code
 {
     "groups": [{
         "key": "base",
@@ -97,11 +85,11 @@ public:
         ]
     }]
 }
-\endcode
+@endcode
 
     How to read/write key and value:
 
-    \code
+    @code
     // init a storage backend
     QTemporaryFile tmpFile;
     tmpFile.open();
@@ -118,66 +106,66 @@ public:
     // modify value
     opt->setValue("Test")
     qDebug() << opt->value();
-   \endcode
-   \sa Dtk::Core::DSettingsOption
-   \sa Dtk::Core::DSettingsGroup
-   \sa Dtk::Core::DSettingsBackend
-   \sa Dtk::Widget::DSettingsWidgetFactory
-   \sa Dtk::Widget::DSettingsDialog
+   @endcode
+   @sa Dtk::Core::DSettingsOption
+   @sa Dtk::Core::DSettingsGroup
+   @sa Dtk::Core::DSettingsBackend
+   @sa Dtk::Widget::DSettingsWidgetFactory
+   @sa Dtk::Widget::DSettingsDialog
  */
 
 /*!
-  \fn virtual QStringList DSettingsBackend::keys() const = 0;
-  \brief return all key of storage.
-  \brief 返回全部键值。
+@~english
+  @fn virtual QStringList DSettingsBackend::keys() const = 0;
+  @brief return all key of storage.
  */
 /*!
-  \fn virtual QVariant DSettingsBackend::getOption(const QString &key) const = 0;
-  \brief get value by \a key.
-  \brief 获取 \a key 对应的值。
+@~english
+  @fn virtual QVariant DSettingsBackend::getOption(const QString &key) const = 0;
+  @brief get value by \a key.
  */
 /*!
-  \fn virtual void DSettingsBackend::doSync() = 0;
-  \brief do the real sync action.
-  \brief 开始进行同步。
+@~english
+  @fn virtual void DSettingsBackend::doSync() = 0;
+  @brief do the real sync action.
  */
 /*!
-  \fn virtual void DSettingsBackend::doSetOption(const QString &key, const QVariant &value) = 0;
-  \brief write \a key / \a value to storage.
-  \brief 设置key对应的值，并使用存储后端进行存储。
+@~english
+  @fn virtual void DSettingsBackend::doSetOption(const QString &key, const QVariant &value) = 0;
+  @brief write \a key / \a value to storage.
  */
 /*!
-  \fn void DSettingsBackend::optionChanged(const QString &key, const QVariant &value);
-  \brief emitted when option \a value changed.
-  \brief DSettingsOption的值发生变化时发出的信号.
-
-  \a key 发生改变的 option 键，\a value 对应键的值.
+@~english
+  @fn void DSettingsBackend::optionChanged(const QString &key, const QVariant &value);
+  @brief emitted when option \a value changed.
  */
 /*!
-  \fn void DSettingsBackend::sync();
-  \brief private signal, please do not use it.
-  \brief 私有信号，请勿使用。
+@~english
+  @fn void DSettingsBackend::sync();
+  @brief private signal, please do not use it.
  */
 /*!
-  \fn void DSettingsBackend::setOption(const QString &key, const QVariant &value);
-  \brief private signal, please do not use it.
-  \brief 私有信号，请勿使用.
+@~english
+  @fn void DSettingsBackend::setOption(const QString &key, const QVariant &value);
+  @brief private signal, please do not use it.
 
   \internal
   \a key \a value
  */
 
 /*!
- \class Dtk::Core::DSettings
+@~english
+ @class Dtk::Core::DSettings
  \inmodule dtkcore
- \brief DSettings是设计上为Dtk的应用程序提供统一的配置存储以及界面生成工具的基础库.
+ @brief DSettings is the basic library that provides unified configuration storage and interface generation tools for Dtk applications.
 
- DSetting使用json作为应用配置程序的描述文件。简单来说，应用查询的配置分为组/键值二个基础层级，
- 对于一个标准的Dtk配置控件，一般只包含组/子组/键值三个层级，对于超过三个层级的键值，可以通过
- DSettings的API接口进行读取和写入，但是不能在标准的DSettingsDialogs上显示出来。
+ DSetting uses json as the description file for the application configuration. The configuration of application query is divided into two basic levels: group / key value.
+ The standard Dtk configuration control generally contains only three levels of group / subgroup / key values. For keys with more than three levels, you can use the.
+ DSettings's API interface reads and writes, but cannot be displayed on standard DSettingsDialogs.
 
- 一个简单的配置文件如下：
-\code
+ 
+ Simple configuration file：
+@code
 {
     "groups": [{
         "key": "base",
@@ -219,35 +207,35 @@ public:
         ]
     }]
 }
-\endcode
+@endcode
 
-改组中包含一个base的root组，两个子组: open_action/new_tab_windows,每个子组有包含若干选项。
-对于"New Window Open:"这个配置，其完整的访问id为base.new_tab_windows.new_window_path。
-读取/设置其值的示例如下:
+The group contains a root group of base with two subgroups: open_action/new_tab_windows, each of which contains several options.
+The complete access id for the configuration "New Window Open:" is base.new_tab_windows.new_window_path.
 
-\code
-    // 初始化一个存储后端
+How to read/write key and value:
+@code
+    // init a storage backend
     QTemporaryFile tmpFile;
     tmpFile.open();
     auto backend = new Dtk::Core::QSettingBackend(tmpFile.fileName());
 
-    // 从json中初始化配置
+    // read settings from json
     auto settings = Dtk::Core::DSettings::fromJsonFile(":/resources/data/dfm-settings.json");
     settings->setBackend(backend);
 
-    // 读取配置
+    // read value
     auto opt = settings->option("base.new_tab_windows.new_window_path");
     qDebug() << opt->value();
 
-    // 修改配置
+    // modify value
     opt->setValue("Test")
     qDebug() << opt->value();
-\endcode
-\sa Dtk::Core::DSettingsOption
-\sa Dtk::Core::DSettingsGroup
-\sa Dtk::Core::DSettingsBackend
-\sa Dtk::Widget::DSettingsWidgetFactory
-\sa Dtk::Widget::DSettingsDialog
+@endcode
+@sa Dtk::Core::DSettingsOption
+@sa Dtk::Core::DSettingsGroup
+@sa Dtk::Core::DSettingsBackend
+@sa Dtk::Widget::DSettingsWidgetFactory
+@sa Dtk::Widget::DSettingsDialog
 */
 
 DSettings::DSettings(QObject *parent) :
@@ -297,7 +285,8 @@ void DSettings::setBackend(DSettingsBackend *backend)
 }
 
 /*!
-   \brief 从 \a json 中获取 DSettings， 返回的数据使用之后需要自己手动释放。
+@~english
+   @brief Get DSettings from \a json. The returned data needs to be manually released after use.
  */
 QPointer<DSettings> DSettings::fromJson(const QByteArray &json)
 {
@@ -357,9 +346,10 @@ QList<QPointer<DSettingsGroup> > DSettings::groups() const
     return d->childGroups.values();
 }
 /*!
-  \brief DSettings::group will recurrence find childGroup
+@~english
+  @brief DSettings::group will recurrence find childGroup
   \a key
-  \return
+  @return
  */
 QPointer<DSettingsGroup> DSettings::group(const QString &key) const
 {
