@@ -1,35 +1,6 @@
-/****************************************************************************
-**
-** Copyright (C) 2015 The Qt Company Ltd.
-** Contact: http://www.qt.io/licensing/
-**
-** This file is part of the tools applications of the Qt Toolkit.
-**
-** $QT_BEGIN_LICENSE:LGPL21$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see http://www.qt.io/terms-conditions. For further
-** information use the contact form at http://www.qt.io/contact-us.
-**
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 or version 3 as published by the Free
-** Software Foundation and appearing in the file LICENSE.LGPLv21 and
-** LICENSE.LGPLv3 included in the packaging of this file. Please review the
-** following information to ensure the GNU Lesser General Public License
-** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** As a special exception, The Qt Company gives you certain additional
-** rights. These rights are described in The Qt Company LGPL Exception
-** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// SPDX-FileCopyrightText: 2016 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
 
 #include <qbytearray.h>
 #include <qdebug.h>
@@ -44,6 +15,7 @@
 #include <qdbusmetatype.h>
 #include <private/qdbusintrospection_p.h>
 
+#include <QVariant>
 #include <stdio.h>
 #include <stdlib.h>
 
@@ -53,6 +25,11 @@
 
 #define ANNOTATION_NO_WAIT "org.freedesktop.DBus.Method.NoReply"
 
+#if QT_VERSION >= QT_VERSION_CHECK(5,15,0)
+#define endl Qt::endl
+#else
+#define endl endl
+#endif
 static QString globalClassName;
 static QString parentClassName;
 static QString proxyFile;
@@ -61,6 +38,7 @@ static QString inputFile;
 static bool skipNamespaces;
 static bool verbose;
 static bool includeMocs;
+static bool skipIncludeAnnotations;
 static QString commandLine;
 static QStringList includes;
 static QStringList wantedInterfaces;
@@ -79,6 +57,7 @@ static const char help[] =
     "  -N               Don't use namespaces\n"
     "  -p <filename>    Write the proxy code to <filename>\n"
     "  -v               Be verbose.\n"
+    "  -S               Skip include annotation headers from \"types/\".\n"
     "  -V               Show the program version and quit.\n"
     "\n"
     "If the file name given to the options -a and -p does not end in .cpp or .h, the\n"
@@ -97,7 +76,7 @@ static const char includeList[] =
     "#include <QtCore/QStringList>\n"
     "#include <QtCore/QVariant>\n"
     "\n"
-    "#include <DBusExtendedAbstractInterface>\n";
+    "#include <DDBusExtendedAbstractInterface>\n";
 
 static const char forwardDeclarations[] =
     "QT_BEGIN_NAMESPACE\n"
@@ -181,6 +160,9 @@ static void parseCmdLine(QStringList args)
         case 'N':
             skipNamespaces = true;
             break;
+        case 'S':
+            skipIncludeAnnotations = true;
+            break;
 
         case '?':
         case 'h':
@@ -278,7 +260,11 @@ static QString moc(const QString &name)
         return retval;
 
     retval.truncate(retval.length() - 1); // drop the h in .h
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    retval = QString("moc_%1cpp").arg(retval);
+#else
     retval += QLatin1String("moc");
+#endif
     return retval;
 }
 
@@ -332,21 +318,34 @@ static QString classNameForInterface(const QString &interface, ClassType classTy
     return retval;
 }
 
+static QString annotationValue(QDBusIntrospection::Annotations annotations, const QString &name) {
+#if QT_VERSION >= QT_VERSION_CHECK(6, 7, 0)
+    return annotations.value(name).value;
+#else
+    return annotations.value(name);
+#endif
+}
+
 static QByteArray qtTypeName(const QString &signature, const QDBusIntrospection::Annotations &annotations, int paramId = -1, const char *direction = "Out")
 {
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    const auto& type = QDBusMetaType::signatureToMetaType(signature.toLatin1());
+    if (type.id() == QMetaType::Type::UnknownType) {
+#else
     int type = QDBusMetaType::signatureToType(signature.toLatin1());
     if (type == QVariant::Invalid) {
+#endif
         QString annotationName = QString::fromLatin1("org.qtproject.QtDBus.QtTypeName");
         if (paramId >= 0)
             annotationName += QString::fromLatin1(".%1%2").arg(QLatin1String(direction)).arg(paramId);
-        QString qttype = annotations.value(annotationName);
+        QString qttype = annotationValue(annotations, annotationName);
         if (!qttype.isEmpty())
             return qttype.toLatin1();
 
         QString oldAnnotationName = QString::fromLatin1("com.trolltech.QtDBus.QtTypeName");
         if (paramId >= 0)
             oldAnnotationName += QString::fromLatin1(".%1%2").arg(QLatin1String(direction)).arg(paramId);
-        qttype = annotations.value(oldAnnotationName);
+        qttype = annotationValue(annotations, oldAnnotationName);
 
         if (qttype.isEmpty()) {
             fprintf(stderr, "Got unknown type `%s'\n", qPrintable(signature));
@@ -360,7 +359,11 @@ static QByteArray qtTypeName(const QString &signature, const QDBusIntrospection:
         return qttype.toLatin1();
     }
 
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    return type.name();
+#else
     return QVariant::typeToName(QVariant::Type(type));
+#endif
 }
 
 static QString nonConstRefArg(const QByteArray &arg)
@@ -453,11 +456,11 @@ static void writeArgList(QTextStream &ts, const QStringList &argNames,
 
 static QString propertyGetter(const QDBusIntrospection::Property &property)
 {
-    QString getter = property.annotations.value(QLatin1String("org.qtproject.QtDBus.PropertyGetter"));
+    QString getter = annotationValue(property.annotations, "org.qtproject.QtDBus.PropertyGetter");
     if (!getter.isEmpty())
         return getter;
 
-    getter = property.annotations.value(QLatin1String("com.trolltech.QtDBus.propertyGetter"));
+    getter = annotationValue(property.annotations, "com.trolltech.QtDBus.propertyGetter");
     if (!getter.isEmpty()) {
         fprintf(stderr, "Warning: deprecated annotation 'com.trolltech.QtDBus.propertyGetter' found;"
                         " suggest updating to 'org.qtproject.QtDBus.PropertyGetter'\n");
@@ -471,11 +474,11 @@ static QString propertyGetter(const QDBusIntrospection::Property &property)
 
 static QString propertySetter(const QDBusIntrospection::Property &property)
 {
-    QString setter = property.annotations.value(QLatin1String("org.qtproject.QtDBus.PropertySetter"));
+    QString setter = annotationValue(property.annotations, "org.qtproject.QtDBus.PropertySetter");
     if (!setter.isEmpty())
         return setter;
 
-    setter = property.annotations.value(QLatin1String("com.trolltech.QtDBus.propertySetter"));
+    setter = annotationValue(property.annotations, "com.trolltech.QtDBus.propertySetter");
     if (!setter.isEmpty()) {
         fprintf(stderr, "Warning: deprecated annotation 'com.trolltech.QtDBus.propertySetter' found;"
                         " suggest updating to 'org.qtproject.QtDBus.PropertySetter'\n");
@@ -489,7 +492,7 @@ static QString propertySetter(const QDBusIntrospection::Property &property)
 
 static QString propertyNotifier(const QDBusIntrospection::Property &property)
 {
-    QString notifier = property.annotations.value(QLatin1String("org.qtproject.QtDBus.PropertyNotifier"));
+    QString notifier = annotationValue(property.annotations, "org.qtproject.QtDBus.PropertyNotifier");
     if (!notifier.isEmpty())
         return notifier;
 
@@ -500,7 +503,7 @@ static QString propertyNotifier(const QDBusIntrospection::Property &property)
 
 static QString methodName(const QDBusIntrospection::Method &method)
 {
-    QString name = method.annotations.value(QStringLiteral("org.qtproject.QtDBus.MethodName"));
+    QString name = annotationValue(method.annotations, "org.qtproject.QtDBus.MethodName");
     if (!name.isEmpty())
         return name;
 
@@ -597,10 +600,14 @@ static void writeProxy(const QString &filename, const QDBusIntrospection::Interf
 
     QSet<QString> annotations;
     for (const QDBusIntrospection::Interface *interface : interfaces) {
-        for (const auto method : interface->methods) {
+        for (const auto &method : interface->methods) {
             for (int i(0); i != method.outputArgs.size(); ++i) {
                 const QDBusIntrospection::Argument &arg = method.outputArgs[i];
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+                if (QDBusMetaType::signatureToMetaType(arg.type.toLatin1()).id() != QMetaType::Type::UnknownType)
+#else
                 if (QDBusMetaType::signatureToType(arg.type.toLatin1()) != QVariant::Invalid)
+#endif
                     continue;
 
                 annotations << qtTypeName(arg.type, method.annotations, i, "Out");
@@ -608,24 +615,34 @@ static void writeProxy(const QString &filename, const QDBusIntrospection::Interf
 
             for (int i(0); i != method.inputArgs.size(); ++i) {
                 const QDBusIntrospection::Argument &arg = method.inputArgs[i];
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+                if (QDBusMetaType::signatureToMetaType(arg.type.toLatin1()).id() != QMetaType::Type::UnknownType)
+#else
                 if (QDBusMetaType::signatureToType(arg.type.toLatin1()) != QVariant::Invalid)
+#endif
                     continue;
 
                 annotations << qtTypeName(arg.type, method.annotations, i, "In");
             }
         }
 
-        for (const auto property : interface->properties) {
+        for (const auto &property : interface->properties) {
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+            if (QDBusMetaType::signatureToMetaType(property.type.toLatin1()).id() != QMetaType::Type::UnknownType)
+#else
             if (QDBusMetaType::signatureToType(property.type.toLatin1()) != QVariant::Invalid)
+#endif
                 continue;
 
             annotations << qtTypeName(property.type, property.annotations);
         }
     }
 
-    for (const QString &annotation : annotations) {
-        if (annotation.indexOf('<') == -1) {
-            hs << "#include \"types/" << annotation.toLower() << ".h\"" << endl;
+    if (!skipIncludeAnnotations) {
+        for (const QString &annotation : annotations) {
+            if (annotation.indexOf('<') == -1) {
+                hs << "#include \"types/" << annotation.toLower() << ".h\"" << endl;
+            }
         }
     }
     hs << endl;
@@ -633,6 +650,9 @@ static void writeProxy(const QString &filename, const QDBusIntrospection::Interf
     foreach (const QDBusIntrospection::Interface *interface, interfaces) {
         QString className = "__" + classNameForInterface(interface->name, Proxy);
 
+        // using namespace Dtk::Core in cpp
+        cs << "DCORE_USE_NAMESPACE" << endl;
+
         // comment:
         hs << "/*" << endl
            << " * Proxy class for interface " << interface->name << endl
@@ -644,8 +664,8 @@ static void writeProxy(const QString &filename, const QDBusIntrospection::Interf
 
         // private class declare
         hs << "class " << className << "Private;" << endl;
-        // class header:
-        hs << "class " << className << " : public DBusExtendedAbstractInterface" << endl
+        // class header: add Dtk::Core
+        hs << "class " << className << " : public DTK_CORE_NAMESPACE::DDBusExtendedAbstractInterface" << endl
            << "{" << endl
            << "    Q_OBJECT" << endl;
         hs << endl;
@@ -659,7 +679,7 @@ static void writeProxy(const QString &filename, const QDBusIntrospection::Interf
 
         // private class member
         cs << "    // begin member variables" << endl;
-        for (const auto property : interface->properties) {
+        for (const auto &property : interface->properties) {
             QByteArray type = qtTypeName(property.type, property.annotations);
             cs << "    " << type << " " << property.name << ';' << endl;
         }
@@ -688,7 +708,7 @@ static void writeProxy(const QString &filename, const QDBusIntrospection::Interf
            << "    ~" << className << "();" << endl
            << endl;
         cs << className << "::" << className << "(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent)" << endl
-           << "    : DBusExtendedAbstractInterface(service, path, staticInterfaceName(), connection, parent)" << endl
+           << "    : DDBusExtendedAbstractInterface(service, path, staticInterfaceName(), connection, parent)" << endl
            << "    , d_ptr(new " << className << "Private)" << endl
            << "{" << endl;
         if (!interface->properties.isEmpty())
@@ -697,12 +717,20 @@ static void writeProxy(const QString &filename, const QDBusIntrospection::Interf
 
         for (const QString &annotation : annotations) {
             if (annotation.indexOf('<') != -1) {
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+                cs << "    if (QMetaType::fromName(\"" << annotation << "\").id() == QMetaType::UnknownType) {" << endl;
+#else
                 cs << "    if (QMetaType::type(\"" << annotation << "\") == QMetaType::UnknownType) {" << endl;
+#endif
                 cs << "        qRegisterMetaType< " << annotation << " >(\"" << annotation << "\");" << endl;
                 cs << "        qDBusRegisterMetaType< " << annotation << " >();" << endl;
                 cs << "    }" << endl;
             } else {
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+                cs << "    if (QMetaType::fromName(\"" << annotation << "\").id() == QMetaType::UnknownType)" << endl;
+#else
                 cs << "    if (QMetaType::type(\"" << annotation << "\") == QMetaType::UnknownType)" << endl;
+#endif
                 cs << "        register" << annotation << "MetaType();" << endl;
             }
         }
@@ -721,10 +749,10 @@ static void writeProxy(const QString &filename, const QDBusIntrospection::Interf
             cs << "void " << className << "::onPropertyChanged(const QString &propName, const QVariant &value)" << endl;
             cs << "{" << endl;
 
-            for (const auto property : interface->properties) {
+            for (const auto &property : interface->properties) {
                 char first = property.name[0].toLatin1();
                 QString name = property.name;
-                name[0] = first & ~0x20;
+                name[0] = QChar(first & ~0x20);
 
                 QByteArray type = qtTypeName(property.type, property.annotations);
 
@@ -806,9 +834,9 @@ static void writeProxy(const QString &filename, const QDBusIntrospection::Interf
         // methods:
         hs << "public Q_SLOTS: // METHODS" << endl;
         foreach (const QDBusIntrospection::Method &method, interface->methods) {
-            bool isDeprecated = method.annotations.value(QLatin1String("org.freedesktop.DBus.Deprecated")) == QLatin1String("true");
+            bool isDeprecated = annotationValue(method.annotations, "org.freedesktop.DBus.Deprecated") == QLatin1String("true");
             bool isNoReply =
-                method.annotations.value(QLatin1String(ANNOTATION_NO_WAIT)) == QLatin1String("true");
+                annotationValue(method.annotations, QLatin1String(ANNOTATION_NO_WAIT)) == QLatin1String("true");
             if (isNoReply && !method.outputArgs.isEmpty()) {
                 fprintf(stderr, "warning: method %s in interface %s is marked 'no-reply' but has output arguments.\n",
                         qPrintable(method.name), qPrintable(interface->name));
@@ -928,7 +956,7 @@ static void writeProxy(const QString &filename, const QDBusIntrospection::Interf
         hs << "Q_SIGNALS: // SIGNALS" << endl;
         foreach (const QDBusIntrospection::Signal &signal, interface->signals_) {
             hs << "    ";
-            if (signal.annotations.value(QLatin1String("org.freedesktop.DBus.Deprecated")) == QLatin1String("true"))
+            if (annotationValue(signal.annotations, QLatin1String("org.freedesktop.DBus.Deprecated")) == QLatin1String("true"))
                 hs << "Q_DECL_DEPRECATED ";
 
             hs << "void " << signal.name << "(";
@@ -1229,7 +1257,7 @@ static void writeAdaptor(const QString &filename, const QDBusIntrospection::Inte
         hs << "public Q_SLOTS: // METHODS" << endl;
         foreach (const QDBusIntrospection::Method &method, interface->methods) {
             bool isNoReply =
-                method.annotations.value(QLatin1String(ANNOTATION_NO_WAIT)) == QLatin1String("true");
+                annotationValue(method.annotations, QLatin1String(ANNOTATION_NO_WAIT)) == QLatin1String("true");
             if (isNoReply && !method.outputArgs.isEmpty()) {
                 fprintf(stderr, "warning: method %s in interface %s is marked 'no-reply' but has output arguments.\n",
                         qPrintable(method.name), qPrintable(interface->name));
@@ -1237,7 +1265,7 @@ static void writeAdaptor(const QString &filename, const QDBusIntrospection::Inte
             }
 
             hs << "    ";
-            if (method.annotations.value(QLatin1String("org.freedesktop.DBus.Deprecated")) == QLatin1String("true"))
+            if (annotationValue(method.annotations, QLatin1String("org.freedesktop.DBus.Deprecated")) == QLatin1String("true"))
                 hs << "Q_DECL_DEPRECATED ";
 
             QByteArray returnType;
@@ -1337,7 +1365,7 @@ static void writeAdaptor(const QString &filename, const QDBusIntrospection::Inte
         hs << "Q_SIGNALS: // SIGNALS" << endl;
         foreach (const QDBusIntrospection::Signal &signal, interface->signals_) {
             hs << "    ";
-            if (signal.annotations.value(QLatin1String("org.freedesktop.DBus.Deprecated")) == QLatin1String("true"))
+            if (annotationValue(signal.annotations, QLatin1String("org.freedesktop.DBus.Deprecated")) == QLatin1String("true"))
                 hs << "Q_DECL_DEPRECATED ";
 
             hs << "void " << signal.name << "(";
